@@ -36,11 +36,13 @@ module VagrantPlugins
           @cpu_features = config.cpu_features
           @cpu_topology = config.cpu_topology
           @features = config.features
+          @features_hyperv = config.features_hyperv
           @cpu_mode = config.cpu_mode
           @cpu_model = config.cpu_model
           @cpu_fallback = config.cpu_fallback
           @numa_nodes = config.numa_nodes
           @loader = config.loader
+          @nvram = config.nvram
           @machine_type = config.machine_type
           @machine_arch = config.machine_arch
           @disk_bus = config.disk_bus
@@ -94,6 +96,9 @@ module VagrantPlugins
           # Watchdog device
           @watchdog_dev = config.watchdog_dev
 
+          # USB controller
+          @usbctl_dev = config.usbctl_dev
+
           # USB device passthrough
           @usbs = config.usbs
 
@@ -128,13 +133,15 @@ module VagrantPlugins
           # If we have a box, take the path from the domain volume and set our storage_prefix.
           # If not, we dump the storage pool xml to get its defined path.
           # the default storage prefix is typically: /var/lib/libvirt/images/
-          if env[:machine].config.vm.box
-            storage_prefix = File.dirname(@domain_volume_path) + '/' # steal
-          else
-            storage_pool = env[:machine].provider.driver.connection.client.lookup_storage_pool_by_name(@storage_pool_name)
-            raise Errors::NoStoragePool if storage_pool.nil?
-            xml = Nokogiri::XML(storage_pool.xml_desc)
-            storage_prefix = xml.xpath('/pool/target/path').inner_text.to_s + '/'
+          if !config.qemu_use_session
+            if env[:machine].config.vm.box
+              storage_prefix = File.dirname(@domain_volume_path) + '/' # steal
+            else
+              storage_pool = env[:machine].provider.driver.connection.client.lookup_storage_pool_by_name(@storage_pool_name)
+              raise Errors::NoStoragePool if storage_pool.nil?
+              xml = Nokogiri::XML(storage_pool.xml_desc)
+              storage_prefix = xml.xpath('/pool/target/path').inner_text.to_s + '/'
+            end
           end
 
           @disks.each do |disk|
@@ -180,19 +187,22 @@ module VagrantPlugins
           if not @cpu_topology.empty?
             env[:ui].info(" -- CPU topology:   sockets=#{@cpu_topology[:sockets]}, cores=#{@cpu_topology[:cores]}, threads=#{@cpu_topology[:threads]}")
           end
-          env[:ui].info("")
           @cpu_features.each do |cpu_feature|
             env[:ui].info(" -- CPU Feature:       name=#{cpu_feature[:name]}, policy=#{cpu_feature[:policy]}")
           end
           @features.each do |feature|
             env[:ui].info(" -- Feature:           #{feature}")
           end
+          @features_hyperv.each do |feature|
+            env[:ui].info(" -- Feature (HyperV):  name=#{feature[:name]}, state=#{feature[:state]}")
+          end
           env[:ui].info(" -- Memory:            #{@memory_size / 1024}M")
           @memory_backing.each do |backing|
             env[:ui].info(" -- Memory Backing:    #{backing[:name]}: #{backing[:config].map { |k,v| "#{k}='#{v}'"}.join(' ')}")
           end
           env[:ui].info(" -- Management MAC:    #{@management_network_mac}")
           env[:ui].info(" -- Loader:            #{@loader}")
+          env[:ui].info(" -- Nvram:             #{@nvram}")
           if env[:machine].config.vm.box
             env[:ui].info(" -- Base box:          #{env[:machine].box.name}")
           end
@@ -256,6 +266,12 @@ module VagrantPlugins
             env[:ui].info(" -- Watchdog device:   model=#{@watchdog_dev[:model]}, action=#{@watchdog_dev[:action]}")
           end
 
+          if not @usbctl_dev.empty?
+            msg = " -- USB controller:    model=#{@usbctl_dev[:model]}"
+            msg += ", ports=#{@usbctl_dev[:ports]}" if @usbctl_dev[:ports]
+            env[:ui].info(msg)
+          end
+
           @usbs.each do |usb|
             usb_dev = []
             usb_dev.push("bus=#{usb[:bus]}") if usb[:bus]
