@@ -4,7 +4,7 @@ module VagrantPlugins
       # This can be used with "Call" built-in to check if the machine
       # is created and branch in the middleware.
       class IsCreated
-        def initialize(app, env)
+        def initialize(app, _env)
           @app = app
         end
 
