@@ -2,12 +2,12 @@ module VagrantPlugins
   module ProviderLibvirt
     module Action
       class MessageNotSuspended
-        def initialize(app, env)
+        def initialize(app, _env)
           @app = app
         end
 
         def call(env)
-          env[:ui].info(I18n.t("vagrant_libvirt.not_suspended"))
+          env[:ui].info(I18n.t('vagrant_libvirt.not_suspended'))
           @app.call(env)
         end
       end
