@@ -1,12 +1,12 @@
-require "log4r"
+require 'log4r'
 
 module VagrantPlugins
   module ProviderLibvirt
     module Action
       class ReadMacAddresses
-        def initialize(app, env)
+        def initialize(app, _env)
           @app    = app
-          @logger = Log4r::Logger.new("vagrant_libvirt::action::read_mac_addresses")
+          @logger = Log4r::Logger.new('vagrant_libvirt::action::read_mac_addresses')
         end
 
         def call(env)
@@ -19,21 +19,19 @@ module VagrantPlugins
           domain = libvirt.client.lookup_domain_by_uuid(machine.id)
 
           if domain.nil?
-            @logger.info("Machine could not be found, assuming it got destroyed")
+            @logger.info('Machine could not be found, assuming it got destroyed')
             machine.id = nil
             return nil
           end
 
           xml = Nokogiri::XML(domain.xml_desc)
-          mac = xml.xpath("/domain/devices/interface/mac/@address")
+          mac = xml.xpath('/domain/devices/interface/mac/@address')
 
-          if mac.length == 0
-            return {}
-          end
+          return {} if mac.empty?
 
-          Hash[mac.each_with_index.map do |x,i|
+          Hash[mac.each_with_index.map do |x, i|
             @logger.debug("interface[#{i}] = #{x.value}")
-            [i,x.value]
+            [i, x.value]
           end]
         end
       end
