@@ -23,9 +23,13 @@ module VagrantPlugins
 
             libvirt_domain = env[:machine].provider.driver.connection.client.lookup_domain_by_uuid(env[:machine].id)
 
-            if config.memory.to_i * 1024 != libvirt_domain.max_memory
-              libvirt_domain.max_memory = config.memory.to_i * 1024
-              libvirt_domain.memory = libvirt_domain.max_memory
+            # libvirt API doesn't support modifying memory on NUMA enabled CPUs
+            # http://libvirt.org/git/?p=libvirt.git;a=commit;h=d174394105cf00ed266bf729ddf461c21637c736
+            if config.numa_nodes == nil
+              if config.memory.to_i * 1024 != libvirt_domain.max_memory
+                libvirt_domain.max_memory = config.memory.to_i * 1024
+                libvirt_domain.memory = libvirt_domain.max_memory
+              end
             end
             begin
               # XML definition manipulation
@@ -124,7 +128,7 @@ module VagrantPlugins
                     cpu.delete_element(svm_feature)
                   end
                 end
-              else
+              elsif config.numa_nodes == nil
                 unless cpu.elements.to_a.empty?
                   descr_changed = true
                   cpu.elements.each do |elem|
