@@ -5,21 +5,21 @@ module VagrantPlugins
     module Action
       # Suspend domain.
       class SuspendDomain
-        def initialize(app, env)
-          @logger = Log4r::Logger.new("vagrant_libvirt::action::suspend_domain")
+        def initialize(app, _env)
+          @logger = Log4r::Logger.new('vagrant_libvirt::action::suspend_domain')
           @app = app
         end
 
         # make pause
         def call(env)
-          env[:ui].info(I18n.t("vagrant_libvirt.suspending_domain"))
+          env[:ui].info(I18n.t('vagrant_libvirt.suspending_domain'))
 
           domain = env[:machine].provider.driver.connection.servers.get(env[:machine].id.to_s)
-          raise Errors::NoDomainError if domain == nil
+          raise Errors::NoDomainError if domain.nil?
 
           config = env[:machine].provider_config
           if config.suspend_mode == 'managedsave'
-            libvirt_domain =  env[:machine].provider.driver.connection.client.lookup_domain_by_uuid(env[:machine].id)
+            libvirt_domain = env[:machine].provider.driver.connection.client.lookup_domain_by_uuid(env[:machine].id)
             begin
               libvirt_domain.managed_save
             rescue => e
