@@ -40,11 +40,13 @@ module VagrantPlugins
       # Libvirt storage pool name, where box image and instance snapshots will
       # be stored.
       attr_accessor :storage_pool_name
+      attr_accessor :storage_pool_path
 
       # Turn on to prevent hostname conflicts
       attr_accessor :random_hostname
 
       # Libvirt default network
+      attr_accessor :management_network_device
       attr_accessor :management_network_name
       attr_accessor :management_network_address
       attr_accessor :management_network_mode
@@ -54,6 +56,9 @@ module VagrantPlugins
       attr_accessor :management_network_pci_bus
       attr_accessor :management_network_pci_slot
 
+      # System connection information
+      attr_accessor :system_uri
+
       # Default host prefix (alternative to use project folder name)
       attr_accessor :default_prefix
 
@@ -69,8 +74,10 @@ module VagrantPlugins
       attr_accessor :cpu_features
       attr_accessor :cpu_topology
       attr_accessor :features
+      attr_accessor :features_hyperv
       attr_accessor :numa_nodes
       attr_accessor :loader
+      attr_accessor :nvram
       attr_accessor :boot_order
       attr_accessor :machine_type
       attr_accessor :machine_arch
@@ -126,6 +133,9 @@ module VagrantPlugins
       # Watchdog device
       attr_accessor :watchdog_dev
 
+      # USB controller
+      attr_accessor :usbctl_dev
+
       # USB device passthrough
       attr_accessor :usbs
 
@@ -148,6 +158,9 @@ module VagrantPlugins
       # Additional qemuargs arguments
       attr_accessor :qemu_args
 
+      # Use qemu session instead of system
+      attr_accessor :qemu_use_session
+
       def initialize
         @uri               = UNSET_VALUE
         @driver            = UNSET_VALUE
@@ -158,6 +171,7 @@ module VagrantPlugins
         @id_ssh_key_file   = UNSET_VALUE
         @storage_pool_name = UNSET_VALUE
         @random_hostname   = UNSET_VALUE
+        @management_network_device  = UNSET_VALUE
         @management_network_name    = UNSET_VALUE
         @management_network_address = UNSET_VALUE
         @management_network_mode = UNSET_VALUE
@@ -167,6 +181,9 @@ module VagrantPlugins
         @management_network_pci_slot = UNSET_VALUE
         @management_network_pci_bus = UNSET_VALUE
 
+        # System connection information
+        @system_uri      = UNSET_VALUE
+
         # Domain specific settings.
         @uuid              = UNSET_VALUE
         @memory            = UNSET_VALUE
@@ -178,8 +195,10 @@ module VagrantPlugins
         @cpu_features      = UNSET_VALUE
         @cpu_topology      = UNSET_VALUE
         @features          = UNSET_VALUE
+        @features_hyperv   = UNSET_VALUE
         @numa_nodes        = UNSET_VALUE
         @loader            = UNSET_VALUE
+        @nvram             = UNSET_VALUE
         @machine_type      = UNSET_VALUE
         @machine_arch      = UNSET_VALUE
         @machine_virtual_size = UNSET_VALUE
@@ -231,6 +250,9 @@ module VagrantPlugins
         # Watchdog device
         @watchdog_dev      = UNSET_VALUE
 
+        # USB controller
+        @usbctl_dev        = UNSET_VALUE
+
         # USB device passthrough
         @usbs              = UNSET_VALUE
 
@@ -251,6 +273,7 @@ module VagrantPlugins
         @mgmt_attach       = UNSET_VALUE
 
         @qemu_args  = []
+        @qemu_use_session  = UNSET_VALUE
       end
 
       def boot(device)
@@ -321,6 +344,14 @@ module VagrantPlugins
                            policy: options[:policy])
       end
 
+      def hyperv_feature(options = {})
+        if options[:name].nil? || options[:state].nil?
+          raise 'Feature name AND state must be specified'
+        end
+
+        @features_hyperv = [{name: options[:name], state: options[:state]}]  if @features_hyperv == UNSET_VALUE
+      end
+
       def cputopology(options = {})
         if options[:sockets].nil? || options[:cores].nil? || options[:threads].nil?
           raise 'CPU topology must have all of sockets, cores and threads specified'
@@ -332,7 +363,7 @@ module VagrantPlugins
 
         @cpu_topology[:sockets] = options[:sockets]
         @cpu_topology[:cores] = options[:cores]
-        @cpu_topology[:threads] = options[:threads]        
+        @cpu_topology[:threads] = options[:threads]
       end
 
       def memorybacking(option, config = {})
@@ -419,6 +450,19 @@ module VagrantPlugins
       end
 
 
+      def usb_controller(options = {})
+        if options[:model].nil?
+          raise 'USB controller model must be specified.'
+        end
+
+        if @usbctl_dev == UNSET_VALUE
+            @usbctl_dev = {}
+        end
+
+        @usbctl_dev[:model] = options[:model]
+        @usbctl_dev[:ports] = options[:ports]
+      end
+
       def usb(options = {})
         if (options[:bus].nil? || options[:device].nil?) && options[:vendor].nil? && options[:product].nil?
           raise 'Bus and device and/or vendor and/or product must be specified. Check `lsusb` for these.'
@@ -447,9 +491,9 @@ module VagrantPlugins
         @redirfilters = [] if @redirfilters == UNSET_VALUE
 
         @redirfilters.push(class: options[:class] || -1,
-                           vendor: options[:class] || -1,
-                           product: options[:class] || -1,
-                           version: options[:class] || -1,
+                           vendor: options[:vendor] || -1,
+                           product: options[:product] || -1,
+                           version: options[:version] || -1,
                            allow: options[:allow])
       end
 
@@ -542,7 +586,9 @@ module VagrantPlugins
         # Setup connection uri.
         uri = @driver.dup
         virt_path = case uri
-                    when 'qemu', 'openvz', 'uml', 'phyp', 'parallels', 'kvm'
+                    when 'qemu', 'kvm'
+                      @qemu_use_session ? '/session' : '/system'
+                    when 'openvz', 'uml', 'phyp', 'parallels'
                       '/system'
                     when '@en', 'esx'
                       '/'
@@ -592,7 +638,9 @@ module VagrantPlugins
         @password = nil if @password == UNSET_VALUE
         @id_ssh_key_file = 'id_rsa' if @id_ssh_key_file == UNSET_VALUE
         @storage_pool_name = 'default' if @storage_pool_name == UNSET_VALUE
+        @storage_pool_path = nil if @storage_pool_path == UNSET_VALUE
         @random_hostname = false if @random_hostname == UNSET_VALUE
+        @management_network_device = 'virbr0' if @management_network_device == UNSET_VALUE
         @management_network_name = 'vagrant-libvirt' if @management_network_name == UNSET_VALUE
         @management_network_address = '192.168.121.0/24' if @management_network_address == UNSET_VALUE
         @management_network_mode = 'nat' if @management_network_mode == UNSET_VALUE
@@ -601,6 +649,9 @@ module VagrantPlugins
         @management_network_autostart = false if @management_network_autostart == UNSET_VALUE
         @management_network_pci_bus = nil if @management_network_pci_bus == UNSET_VALUE
         @management_network_pci_slot = nil if @management_network_pci_slot == UNSET_VALUE
+        @system_uri      = 'qemu:///system' if @system_uri == UNSET_VALUE
+
+        @qemu_use_session = false if @qemu_use_session == UNSET_VALUE
 
         # generate a URI if none is supplied
         @uri = _generate_uri if @uri == UNSET_VALUE
@@ -615,13 +666,17 @@ module VagrantPlugins
                        'qemu64'
                      elsif @cpu_mode != 'custom'
                        ''
+                     else
+                       @cpu_model
           end
         @cpu_topology = {} if @cpu_topology == UNSET_VALUE
         @cpu_fallback = 'allow' if @cpu_fallback == UNSET_VALUE
         @cpu_features = [] if @cpu_features == UNSET_VALUE
         @features = ['acpi','apic','pae'] if @features == UNSET_VALUE
+        @features_hyperv = [] if @features_hyperv == UNSET_VALUE
         @numa_nodes = @numa_nodes == UNSET_VALUE ? nil : _generate_numa
         @loader = nil if @loader == UNSET_VALUE
+        @nvram = nil if @nvram == UNSET_VALUE
         @machine_type = nil if @machine_type == UNSET_VALUE
         @machine_arch = nil if @machine_arch == UNSET_VALUE
         @machine_virtual_size = nil if @machine_virtual_size == UNSET_VALUE
@@ -684,6 +739,9 @@ module VagrantPlugins
         # Watchdog device
         @watchdog_dev = {} if @watchdog_dev == UNSET_VALUE
 
+        # USB controller
+        @usbctl_dev = {} if @usbctl_dev == UNSET_VALUE
+
         # USB device passthrough
         @usbs = [] if @usbs == UNSET_VALUE
 
